@@ -2,6 +2,7 @@ package # hide from CPAN
     Riemann::Client::Transport;
 
 use Moo;
+use Scalar::Util 'blessed';
 use IO::Socket::INET;
 
 has host   => (is => 'ro', required => 1);
@@ -15,13 +16,13 @@ sub send {
 sub _build_socket {
     my $self  = shift;
 
-    my @elems = split /::/, __PACKAGE__;
+    my @elems = split /::/, blessed $self;
     my $proto = $elems[-1];
 
     my $sock = IO::Socket::INET->new(
         PeerAddr => $self->host,
         PeerPort => $self->port,
-        Proto    => shift,
+        Proto    => $proto,
     ) or die $!;
 
     return $sock;
